@@ -38,14 +38,34 @@ import threading
 
 # Null stream object for supressing logs in request
 class NullStream(object):
+    __slots__ = ()
+
     def write(self, s):
         pass
+
 NULL_STREAM = NullStream()
 
 
 # Top-level WSGI application class
 class Application(object):
 
+    __slots__ = (
+        '__defaultLogger',
+        '__logLevel',
+        '__logFormat',
+        '__prettyOutput',
+        '__validateOutput',
+        '__alwaysReload',
+        '__logStream',
+        '__defaultLogger',
+        '__threadStates',
+        '__callLock',
+        '__specParser',
+        '__requests',
+        '__requestUrls',
+        '__requestUrlRegex',
+        )
+
     ENVIRON_APP = 'chisel.app'
     ENVIRON_JSONP = 'chisel.jsonp'
     ENVIRON_HEADERS = 'chisel.headers'
@@ -353,7 +373,7 @@ class Application(object):
 
             # URL with arguments?
             if self.__reUrlArg.search(url):
-                urlRegex = self.__reUrlArgEsc.sub('/(?P<\\1>[^/]+)', re.escape(url))
+                urlRegex = '^' + self.__reUrlArgEsc.sub('/(?P<\\1>[^/]+)', re.escape(url)) + '$'
                 self.__requestUrlRegex.append((re.compile(urlRegex), request))
             else:
                 if url in self.__requestUrls:
